@@ -6,6 +6,8 @@
 ( cd opt/kde/share/doc/HTML/es/kdm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kpf ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/ktuberling ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/ktuberling ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/amor ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/karm ; rm -rf common )
@@ -14,16 +16,24 @@
 ( cd opt/kde/share/doc/HTML/es/kdat ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kdvi ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kgpg ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kmag ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmid ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kmid ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmix ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kmix ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kodo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kodo ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kolf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kolf ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kpat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kpat ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kpdf ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/korn ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kppp ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kppp ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kscd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kscd ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/ksim ; rm -rf common )
@@ -38,6 +48,10 @@
 ( cd opt/kde/share/doc/HTML/es/ksysguard ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kbounce ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kdelirc/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kdelirc/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kbattleship ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kaboodle ; rm -rf common )
@@ -68,14 +82,20 @@
 ( cd opt/kde/share/doc/HTML/es/kjots ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmail ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kmail ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kmoon ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kmoon ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/knode ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/knode ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kooka ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kooka ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/ksame ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/ksame ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/ktnef ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/ksysv ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/ktron ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/ktron ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kuser ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kview ; rm -rf common )
@@ -84,14 +104,20 @@
 ( cd opt/kde/share/doc/HTML/es/kwin4 ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/lskat ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kgoldrunner ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kcoloredit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/klipper ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kvoctrain ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kmousetool ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kompare ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kontact ; rm -rf common )
@@ -116,6 +142,8 @@
 ( cd opt/kde/share/doc/HTML/es/ksirtet ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/konquest ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/konquest ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kspaceduel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kverbos ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kwallet ; rm -rf common )
@@ -124,6 +152,8 @@
 ( cd opt/kde/share/doc/HTML/es/kweather ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kwuftpd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kwifimanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kbugbuster ; rm -rf common )
@@ -342,6 +372,8 @@
 ( cd opt/kde/share/doc/HTML/es/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/konq-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kbabel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kbabel ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kalarm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kalarm ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kamera ; rm -rf common )
@@ -396,28 +428,40 @@
 ( cd opt/kde/share/doc/HTML/es/kblackbox ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kcharselect ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/quanta ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kuickshow ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kommander ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kommander ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kiconedit ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/klettres ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kfouleggs ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kghostview ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/klickety ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kleopatra ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kenolaba ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kgpgcertmanager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kworldclock ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/KRegExpEditor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/es/common common )
+( cd opt/kde/share/doc/HTML/es/ksokoban ; rm -rf common )
+( cd opt/kde/share/doc/HTML/es/ksokoban ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kteatime ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kmathtool ; rm -rf common )
@@ -458,8 +502,6 @@
 ( cd opt/kde/share/doc/HTML/es/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/kinfocenter/protocols ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/es/common common )
-( cd opt/kde/share/doc/HTML/es/kate-plugins ; rm -rf common )
-( cd opt/kde/share/doc/HTML/es/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/korganizer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/es/korganizer ; ln -sf /opt/kde/share/doc/HTML/es/common common )
 ( cd opt/kde/share/doc/HTML/es/atlantik ; rm -rf common )
